@@ -324,13 +324,18 @@ void ScalingObject::setBoolValue(bool value)
 }
 
 
-ObjectController::ObjectController()
+ObjectController::ObjectController() : con_m(0)
 {
 }
 
 ObjectController::~ObjectController()
 {
   Stop ();
+  if (con_m)
+    EIBClose(con_m);
+  ObjectIdMap_t::iterator it;
+  for (it = objectIdMap_m.begin(); it != objectIdMap_m.end(); it++)
+    delete (*it).second;
 }
 
 ObjectController* ObjectController::instance()
@@ -401,7 +406,12 @@ void ObjectController::Run (pth_sem_t * stop1)
           (*it).second->onWrite(buf, len);
       }
     }
-    
+/*  TODO: find another way to check if event occured
+    struct timeval tv;
+	  tv.tv_sec = 1;
+  	tv.tv_usec = 0;
+    pth_select_ev(0,0,0,0,&tv,stop);
+*/    
   }
   std::cout << "Out of ObjectController loop." << std::endl;
   pth_event_free (stop, PTH_FREE_THIS);
