@@ -167,6 +167,22 @@ private:
     float value_m;
 };
 
+class SendSmsAction : public Action
+{
+public:
+    SendSmsAction();
+    virtual ~SendSmsAction();
+
+    virtual void importXml(ticpp::Element* pConfig);
+    virtual void exportXml(ticpp::Element* pConfig);
+
+private:
+    virtual void Run (pth_sem_t * stop);
+
+    std::string id_m;
+    std::string value_m;
+};
+
 class Rule : public ChangeListener
 {
 public:
