@@ -135,49 +135,78 @@ ClientConnection::Run (pth_sem_t * stop1)
 			{
 				// Load a document
 				ticpp::Document doc;
-        std::cout << "PROCESSING MESSAGE:" << std::endl << msg_m << std::endl << "END OF MESSAGE" << std::endl;
+//        std::cout << "PROCESSING MESSAGE:" << std::endl << msg_m << std::endl << "END OF MESSAGE" << std::endl;
 				doc.LoadFromString(msg_m);
-            throw "check memleak";
 		
 				ticpp::Element* pMsg = doc.FirstChildElement();
-        if (pMsg->Value() == "config")
+        if (pMsg->Value() == "read")
         {
-  				ticpp::Element* pConfigItem = pMsg->FirstChildElement();
-          if (pConfigItem->Value() == "objects")
-  					ObjectController::instance()->importXml(pConfigItem);
-          else if (pConfigItem->Value() == "exceptiondays")
-  					ExceptionDays::instance()->importXml(pConfigItem);
-          else if (pConfigItem->Value() == "rules")
-  					RuleServer::instance()->importXml(pConfigItem);
+  				ticpp::Element* pRead = pMsg->FirstChildElement();
+          if (pRead->Value() == "object") {
+						std::string id = pRead->GetAttribute("id");
+						Object* obj = ObjectController::instance()->getObject(id);
+						std::stringstream msg;
+						msg << "<read status='success'>" << obj->getFloatValue() << "</resp>" << std::endl;
+						sendmessage (msg.str(), stop);
+          }
+          else if (pRead->Value() == "config") {
+    				ticpp::Element* pConfig = pRead->FirstChildElement(false);
+//						ticpp::Document doc;
+            if (pConfig == 0) {
+							ticpp::Element objects("objects");
+							ObjectController::instance()->exportXml(&objects);
+							pRead->LinkEndChild(&objects);
+
+							ticpp::Element exceptionDays("exceptiondays");
+							ExceptionDays::instance()->exportXml(&exceptionDays);
+							pRead->LinkEndChild(&exceptionDays);
+
+							ticpp::Element rules("rules");
+							RuleServer::instance()->exportXml(&rules);
+							pRead->LinkEndChild(&rules);
+            }
+            else if (pConfig->Value() == "objects") {
+							ObjectController::instance()->exportXml(pConfig);
+            }
+            else if (pConfig->Value() == "exceptiondays") {
+							ExceptionDays::instance()->exportXml(pConfig);
+            }
+            else if (pConfig->Value() == "rules") {
+							RuleServer::instance()->exportXml(pConfig);
+            }
+            pMsg->SetAttribute("status", "success");
+						sendmessage (doc.GetAsString(), stop);
+          }
           else
-            throw "Unknown config element";
-  	      sendmessage ("<resp status='success'>Operation executed</resp>\n", stop);
-        }
-        else if (pMsg->Value() == "read")
-        {
-  				ticpp::Element* pObject = pMsg->FirstChildElement("object");
-          std::string id = pObject->GetAttribute("id");
-          Object* obj = ObjectController::instance()->getObject(id);
-        	std::stringstream msg;
-         	msg << "<resp status='success'>" << obj->getFloatValue() << "</resp>" << std::endl;
-          sendmessage (msg.str(), stop);
+            throw "Unknown read element";
         }
         else if (pMsg->Value() == "write")
         {
-  				ticpp::Element* pObject = pMsg->FirstChildElement("object");
-          std::string id = pObject->GetAttribute("id");
-          float value;
-          pObject->GetAttribute("value", &value);
-          Object* obj = ObjectController::instance()->getObject(id);
-          obj->setFloatValue(value);
-        	std::stringstream msg;
-         	msg << "<resp status='success'>" << obj->getFloatValue() << "</resp>" << std::endl;
-          sendmessage (msg.str(), stop);
+  				ticpp::Element* pWrite = pMsg->FirstChildElement(false);
+          if (pWrite->Value() == "object") {
+	          std::string id = pWrite->GetAttribute("id");
+	          float value;
+	          pWrite->GetAttribute("value", &value);
+	          Object* obj = ObjectController::instance()->getObject(id);
+          	obj->setFloatValue(value);
+          }
+          else if (pWrite->Value() == "config") {
+						ticpp::Element* pConfigItem = pWrite->FirstChildElement();
+						if (pConfigItem->Value() == "objects")
+							ObjectController::instance()->importXml(pConfigItem);
+						else if (pConfigItem->Value() == "exceptiondays")
+							ExceptionDays::instance()->importXml(pConfigItem);
+						else if (pConfigItem->Value() == "rules")
+							RuleServer::instance()->importXml(pConfigItem);
+						else
+							throw "Unknown config element";
+					}
+          else
+            throw "Unknown write element";
+					sendmessage ("<write status='success'/>\n", stop);
         }
 				else
-        {
           throw "Unknown element";
-        }
 			}
 			catch( const char* ex )
 			{
@@ -196,7 +225,7 @@ int
 ClientConnection::sendreject (const char* msgstr, pth_event_t stop)
 {
 	std::stringstream msg;
-	msg << "<resp status='error'>" << msgstr << "</resp>" << std::endl;
+	msg << "<error>" << msgstr << "</error>" << std::endl;
 	sendmessage (msg.str(), stop);
 }
 
